#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 implicit-hie
version:              0.1.4.0
visibility:           public
id:                   implicit-hie-0.1.4.0-8DukwtTcbHlE3wafWyXWIK
key:                  implicit-hie-0.1.4.0-8DukwtTcbHlE3wafWyXWIK
license:              BSD-3-Clause
copyright:            2020
maintainer:           avi.the.coder@gmail.com
author:               Avi Dessauer
homepage:             https://github.com/Avi-D-coder/implicit-hie#readme
synopsis:             Auto generate hie-bios cradles & hie.yaml
description:
    Auto generate a stack or cabal multi component hie.yaml file

category:             Development, Tools, Hie, HLS
abi:                  593612a066b12bbcb6aa8287997d776d
exposed:              True
exposed-modules:      Hie.Cabal.Parser Hie.Locate Hie.Yaml
hidden-modules:       Paths_implicit_hie
import-dirs:          /usr/lib/ghc-9.6.6/site-local/implicit-hie-0.1.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/implicit-hie-0.1.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/implicit-hie-0.1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-implicit-hie
hs-libraries:         HSimplicit-hie-0.1.4.0-8DukwtTcbHlE3wafWyXWIK
depends:
    attoparsec-0.14.4-JfqiEkfNFnE8n0O4G6WZl6 base-4.18.2.1
    directory-1.3.8.5 filepath-1.4.300.1
    filepattern-0.1.3-CDLSOuVnlsNFR4yl275IIL text-2.0.2
    transformers-0.6.1.0 yaml-0.11.11.2-JaCnvXVwHr1DIN7Fv30Aj1

haddock-interfaces:
    /usr/share/doc/haskell-implicit-hie/html/implicit-hie.haddock

haddock-html:         /usr/share/doc/haskell-implicit-hie/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

